Cache

Struct Cache 

pub struct Cache<K, V> { /* private fields */ }
LRU-like cache using DashMap Uses atomic counters for LRU approximation and metrics

Implementations

Source

impl<K, V> Cache<K, V>
where K: Hash + Eq + Clone + Send + Sync + 'static, V: Clone + Send + Sync + 'static,

pub fn new(capacity: usize, name: String) -> Result<Cache<K, V>, String>

Creates a new cache with the specified capacity and name

Errors

Returns an error if capacity is 0

Panics

Panics if the system time is before UNIX_EPOCH (should never happen in practice)

pub fn get(&self, key: &K) -> Option<V>

Get value from cache - completely lock-free

pub fn put(&self, key: K, value: V) -> Option<V>

Put value in cache - lock-free with atomic eviction

pub fn contains_key(&self, key: &K) -> bool

Check if key exists - lock-free

pub fn remove(&self, key: &K) -> Option<V>

Remove specific key - lock-free

pub fn clear(&self)

Clear all entries - lock-free

pub fn len(&self) -> usize

Get current size - atomic read

pub fn is_empty(&self) -> bool

Check if empty - atomic read

pub fn capacity(&self) -> usize

Get capacity - atomic read

pub fn get_stats(&self) -> CacheStats

Get cache statistics - all atomic reads Gets comprehensive statistics about the cache

Panics

Panics if the system time is before UNIX_EPOCH (should never happen in practice)

pub fn reset_metrics(&self)

Reset metrics - atomic operations

pub fn resize(&self, new_capacity: usize) -> Result<(), String>

Resize cache capacity - atomic Resizes the cache to a new capacity

Errors

Returns an error if new_capacity is 0 or if eviction fails during resize

pub fn has_performance_issues(&self) -> bool

Check for performance issues - atomic reads only

pub fn get_recommendations(&self) -> Vec<String>

Get performance recommendations

pub fn keys(&self) -> Vec<K>

Get all keys - creates snapshot (potentially expensive)

pub fn values(&self) -> Vec<V>

Get all values - creates snapshot (potentially expensive)

pub fn for_each<F>(&self, f: F)
where F: FnMut(&K, &V),

Iterate over entries with callback - lock-free iteration

pub fn drain_eviction_events(&self) -> Vec<EvictionEvent<K>>

Drain eviction events (for monitoring)