pub struct FreshnessEntry {
pub entry_id: String,
pub file_path: String,
pub status: i32,
pub stored_hash: Vec<u8>,
pub current_hash: Vec<u8>,
}Fields
entry_id: Stringfile_path: Stringstatus: i32stored_hash: Vec<u8>current_hash: Vec<u8>Implementations
Sourceimpl FreshnessEntry
impl FreshnessEntry
Sourcepub fn status(&self) -> FreshnessStatus
pub fn status(&self) -> FreshnessStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: FreshnessStatus)
pub fn set_status(&mut self, value: FreshnessStatus)
Sets status to the provided enum value.