Graph-RAG: Graph-enhanced Retrieval Augmented Generation
This module provides graph-based enrichment for semantic search results. It uses the entity graph to:
- Expand query context with related entities
- Find structural connections between search results
- Add causal chains and relationship paths
Example
ⓘ
let config = GraphRagConfig::default();
let enricher = GraphRagEnricher::new(config);
let enriched = enricher.enrich_results(&graph, query, results).await;Structs
- Global
Graph Insights - Global insights from graph analysis
- Graph
Enrichment - Result of graph enrichment for a single search result
- Graph
RagConfig - Configuration for Graph-RAG enrichment
- Graph
RagEnricher - Graph-RAG enricher that adds graph context to search results
- Relation
Info - Information about a single relation