pub async fn get_key_decisions(
session_id: String,
) -> Result<MCPToolResult, Error>Expand description
Extract a timeline of key architectural and technical decisions.
pub async fn get_key_decisions(
session_id: String,
) -> Result<MCPToolResult, Error>Extract a timeline of key architectural and technical decisions.