pub async fn create_session_checkpoint_with_system(
session_id: Uuid,
system: &ConversationMemorySystem,
) -> Result<MCPToolResult, Error>Expand description
Create a session checkpoint using an explicit memory system reference.
pub async fn create_session_checkpoint_with_system(
session_id: Uuid,
system: &ConversationMemorySystem,
) -> Result<MCPToolResult, Error>Create a session checkpoint using an explicit memory system reference.