pub struct UpdateContextRequest {
pub session_id: String,
pub interaction_type: String,
pub content: Option<ContextContent>,
pub source_ref: Option<SourceReference>,
pub entities: Vec<EntityInfo>,
pub relations: Vec<RelationInfo>,
}Fields
session_id: Stringinteraction_type: StringInteraction type: qa, code_change, problem_solved, decision_made, requirement_added, concept_defined
content: Option<ContextContent>source_ref: Option<SourceReference>Optional source file reference (for freshness tracking)
entities: Vec<EntityInfo>relations: Vec<RelationInfo>Trait Implementations
Sourceimpl Clone for UpdateContextRequest
impl Clone for UpdateContextRequest
Sourcefn clone(&self) -> UpdateContextRequest
fn clone(&self) -> UpdateContextRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateContextRequest
impl Debug for UpdateContextRequest
Sourceimpl Default for UpdateContextRequest
impl Default for UpdateContextRequest
Sourcefn default() -> UpdateContextRequest
fn default() -> UpdateContextRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for UpdateContextRequest
impl Message for UpdateContextRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for UpdateContextRequest
impl PartialEq for UpdateContextRequest
Sourcefn eq(&self, other: &UpdateContextRequest) -> bool
fn eq(&self, other: &UpdateContextRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpdateContextRequest