pub struct SummaryGenerator;Expand description
Main summary generator that uses existing structured data All methods are associated functions (no state needed)
Implementations
Sourceimpl SummaryGenerator
impl SummaryGenerator
Sourcepub fn generate_structured_summary(
session: &ActiveSession,
) -> StructuredSummaryView
pub fn generate_structured_summary( session: &ActiveSession, ) -> StructuredSummaryView
Generate structured summary from existing ActiveSession data
Sourcepub fn generate_structured_summary_filtered(
session: &ActiveSession,
options: &SummaryOptions,
) -> StructuredSummaryView
pub fn generate_structured_summary_filtered( session: &ActiveSession, options: &SummaryOptions, ) -> StructuredSummaryView
Generate filtered/limited structured summary
Sourcepub fn calculate_session_stats(session: &ActiveSession) -> SessionStats
pub fn calculate_session_stats(session: &ActiveSession) -> SessionStats
Calculate session statistics from existing data This is a lightweight operation that doesn’t require full summary generation
Sourcepub fn estimate_summary_size(
session: &ActiveSession,
max_tokens: usize,
) -> (usize, bool)
pub fn estimate_summary_size( session: &ActiveSession, max_tokens: usize, ) -> (usize, bool)
Estimate summary size in tokens without full generation Returns (estimated_tokens, should_use_compact)
Sourcepub fn extract_key_insights(
session: &ActiveSession,
limit: usize,
) -> Vec<String>
pub fn extract_key_insights( session: &ActiveSession, limit: usize, ) -> Vec<String>
Extract key insights from existing data
Sourcepub fn extract_decision_timeline(
session: &ActiveSession,
) -> Vec<DecisionSummary>
pub fn extract_decision_timeline( session: &ActiveSession, ) -> Vec<DecisionSummary>
Extract decision timeline from existing data